@@ -146,8 +146,8 @@ sub _menus {
 sub _sub_menus {
     my ( $key ) = @_;
     my $sub_menus = {
-        _fast_listmenu => [ [ 'fast_list_youtube', "- youtube", [ 'NO', 'YES' ] ],
-                            [ 'fast_list_vimeo',   "- vimeo",   [ 'NO', 'YES' ] ], ],
+        _fast_listmenu => [ [ 'fast_list_vimeo',   "- vimeo",   [ 'NO', 'YES' ] ],
+                          ],
     };
     return $sub_menus->{$key} if $key;
     return $sub_menus;
@@ -418,7 +418,7 @@ sub set_options {
                 my $prompt = 'Videos in list-menu';
                 my $list = [
                     'all',
-                    'latest 50',
+                    'latest',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
